pilas.depurador.ModoPuntosDeControl

Package pilas :: Module depurador :: Class ModoPuntosDeControl |
[hide private]
[frames] | no frames]

# Class ModoPuntosDeControl

source code

       object --+
                |
    ModoDepurador --+
                    |
                   ModoPuntosDeControl

Instance Methods | [hide private]
dibuja_al_actor(self, motor, painter, lienzo, actor) | source code
Inherited from `ModoDepurador`: `__init__`, `comienza_dibujado`, `orden_de_tecla`, `sale_del_modo`, `termina_dibujado` Inherited from `object`: `__delattr__`, `__format__`, `__getattribute__`, `__hash__`, `__new__`, `__reduce__`, `__reduce_ex__`, `__repr__`, `__setattr__`, `__sizeof__`, `__str__`, `__subclasshook__`

Class Variables | [hide private]
| tecla = ``'``F8``'``

Properties | [hide private]
Inherited from `object`: `__class__`

Method Details | [hide private]

### dibuja_al_actor(self, motor, painter, lienzo, actor) | source code
Overrides: ModoDepurador.dibuja_al_actor